LoadingErrorEvent<Query> class

The event can be used when an error occurs in the overridden RecordsLoader.performLoadQuery function.

It should be used to set an error in the list state. Normally, a HandledLoadingException should be thrown after this event is called.

Inheritance
Annotations
  • @immutable

Constructors

LoadingErrorEvent({required Query query, required LoadingKey loadingKey, Object? error})
Creates a new LoadingErrorEvent.
const

Properties

error → Object?
The object describing the problem that occurred.
final
hashCode → int
The hash code for this object.
no setteroverride
loadingKey → String
Key identifying the load.
final
query → Query
A query, the execution of which failed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override