UpdateHotListEvent<Record, Key> class

The event must be called from an overridden function HotList.updateHotList. The handler must perform the same actions as for this function.

Inheritance
Annotations
  • @immutable

Constructors

UpdateHotListEvent({required HotListChanges<Record, Key> changes})
Creates a new UpdateHotListEvent.
const

Properties

changes HotListChanges<Record, Key>
Changes that should be reflected in the list state.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override