ListState<Record, Query> class

Stores the list state.

Implemented types
Annotations
  • @immutable

Constructors

ListState({required Query query, List<Record> records = const [], ListStage stage = const IdleListStage(), bool isInitialized = false})
Creates a list state.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
Whether the list has no records.
no setteroverride
isInitialized → bool
Whether the list is initialized.
final
isLoading → bool
Whether the list is at the stage of loading records.
no setter
query → Query
Description of the criteria of the records included in the list.
final
records → List<Record>
Stores list records.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage → ListStage
Stage the list is at.
final

Methods

copyWith({List<Record>? records, ListStage? stage, Query? query, bool? isInitialized}) → ListState<Record, Query>
Creates a copy of this list state but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override