ListStateMeta class

Stores basic information about the list state.

Implementers

Constructors

ListStateMeta({required bool isEmpty, required ListStage stage, required bool isInitialized})
Creates a description of a list state.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether the list has no records.
final
isInitialized → bool
Whether the list is initialized.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage → ListStage
Stage the list is at.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited