ErrorListStage class
Stage indicating that loading of the list records was unsuccessful.
Constructors
- ErrorListStage({Object? error})
-
Const constructor.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited