ListStage class abstract

A base class for all the stages the list can be in.

Implementers

Constructors

ListStage()
Abstract const constructor.
const
ListStage.complete()
List is complete and has not any pages to load.
factory
ListStage.error()
Loading the list records was unsuccessful.
factory
ListStage.idle()
List is idle.
factory
ListStage.loading()
List is loading.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited