waitAllLoadsToComplete method

Future<void> waitAllLoadsToComplete()
inherited

Returns Future, which completes either immediately if there are no other loads, or upon completion of all loads.

Implementation

Future<void> waitAllLoadsToComplete() {
  return Future.value();
}