HotListChanges<Record, Key> class

Contains records to be added to the list and unique identifiers (keys) of records to be removed from the list.

Annotations
  • @immutable

Constructors

HotListChanges({Set<Record> recordsToInsert = const {}, Set<Key> recordKeysToRemove = const {}})
Creates a new HotListChanges object.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
Whether this object has no records for adding or removing.
no setter
recordKeysToRemove → Set<Key>
List of unique identifiers of records to be removed from the list.
final
recordsToInsert → Set<Record>
List of records to be added to the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override