getListStage abstract method

  1. @protected
ListStage getListStage(
  1. LoadingKey loadingKey
)

The function must convert the current state of the list into an object representing the current stage of the list (ListStage.idle(), ListStage.error(), ListStage.loading(), ListStage.complete()).

Implementation

@protected
ListStage getListStage(LoadingKey loadingKey);