waitAllLoadsToComplete method
Returns Future, which completes either immediately if there are no other loads, or upon completion of all loads.
Implementation
Future<void> waitAllLoadsToComplete() {
return Future.value();
}
Returns Future, which completes either immediately if there are no other loads, or upon completion of all loads.
Future<void> waitAllLoadsToComplete() {
return Future.value();
}